@@ -7,13 +7,13 @@ latitudes = [-34.58, -15.78, -33.45, 4.60, 10.48, -23.55, 13.1]
 longitudes = [-58.66, -47.91, -70.66, -74.08, -66.86, -46.63, -59.62]
 data = {'City': cities,  'Latitude': latitudes, 'Longitude': longitudes}
 cities = starepandas.STAREDataFrame(data)
-stare = starepandas.stare_from_xy(cities.Longitude, cities.Latitude, level=26)
-cities.set_stare(stare, inplace=True)
+stare = starepandas.sids_from_xy(cities.Longitude, cities.Latitude, resolution=26)
+cities.set_sids(stare, inplace=True)
 
 countries = geopandas.read_file(geopandas.datasets.get_path('naturalearth_lowres'))
 samerica = countries[countries.continent == 'South America']
-stare = starepandas.stare_from_gdf(samerica, level=6, force_ccw=True)
-samerica = starepandas.STAREDataFrame(samerica, stare=stare)
+stare = starepandas.sids_from_gdf(samerica, resolution=6, force_ccw=True)
+samerica = starepandas.STAREDataFrame(samerica, sids=stare)
 
 
 def join():
